@@ -13,3 +13,6 @@ $x=6; $y = p(); my $z = p();
 $x = 8;
 $x += $y;
 $x += $z;
+$x += 5;
+$x -= 5;
+
