@@ -19,7 +19,7 @@ use PadWalker qw(peek_my);
 use Devel::Trepan::CmdProcessor::Command::Subcmd::Core;
 
 our $CMD = "info variables my";
-our @CMD = split(/ /, $CMD);
+my  @CMD = split(/ /, $CMD);
 our $MIN_ABBREV = length('m');
 our $HELP   = <<'HELP';
 =pod
@@ -44,6 +44,30 @@ our $SHORT_HELP   = "Information about 'my' variables.";
 
 @ISA = qw(Devel::Trepan::CmdProcessor::Command::Subsubcmd);
 
+sub get_var_hash($;$) 
+{
+    my ($self, $fixup_num) = @_;
+    # FIXME: combine with My.pm
+    my $i = 0;
+    while (my ($pkg, $file, $line, $fn) = caller($i++)) { ; };
+    my $diff = $i - $DB::stack_depth;
+    
+    # FIXME: 5 is a magic fixup constant, also found in DB::finish.
+    # Remove it.
+    $fixup_num = 5 unless defined($fixup_num);
+    my $ref = peek_my($diff + $self->{proc}{frame_index} + $fixup_num);
+    return $ref;
+}
+
+sub complete($$;$)
+{ 
+    my ($self, $prefix, $fixup_num) = @_;
+    my $var_hash = $self->get_var_hash($fixup_num);
+    my @vars = sort keys %$var_hash;
+    Devel::Trepan::Complete::complete_token(\@vars, $prefix) ;
+}
+
+
 sub show_var($$$) 
 {
     my ($proc, $var_name, $ref) = @_;
@@ -77,8 +101,9 @@ sub show_var($$$)
 }
 
 
-sub process_args($$$$) {
-    my ($self, $args, $hash_ref, $lex_type) = @_;
+sub process_args($$$) {
+    my ($self, $args, $hash_ref) = @_;
+    my $lex_type = $self->{prefix}[-1];
     my $proc = $self->{proc};
     my @ARGS = @{$args};
     my @names = sort keys %{$hash_ref};
@@ -112,33 +137,55 @@ sub process_args($$$$) {
     }
 }
 
-sub run($$)
+sub run($$;$)
 {
-    my ($self, $args) = @_;
-    # FIXME: combine with My.pm
-    my $i = 0;
-    while (my ($pkg, $file, $line, $fn) = caller($i++)) { ; };
-    my $diff = $i - $DB::stack_depth;
-
-    # FIXME: 4 is a magic fixup constant, also found in DB::finish.
-    # Remove it.
-    my $var_hash = peek_my($diff + $self->{proc}{frame_index} + 4);
+    my ($self, $args, $fixup_num) = @_;
+    my $var_hash = $self->get_var_hash($fixup_num);
     my @ARGS = splice(@{$args}, scalar(@CMD));
-    $self->process_args(\@ARGS, $var_hash, 'my');
+    $self->process_args(\@ARGS, $var_hash);
 }
 
 unless (caller) { 
     # Demo it.
     require Devel::Trepan;
-    # require_relative '../../mock'
-    # dbgr, parent_cmd = MockDebugger::setup('set', false)
-    # cmd              = Trepan::SubSubcommand::SetMax.new(dbgr.core.processor, 
-    #                                                      parent_cmd)
-    # cmd.run(cmd.prefix + ['string', '30'])
-    
-    # %w(s lis foo).each do |prefix|
-    #   p [prefix, cmd.complete(prefix)]
-    # end
+    my $proc = Devel::Trepan::CmdProcessor->new;
+    my $grandparent = 
+	Devel::Trepan::CmdProcessor::Command::Info->new($proc, 'info');
+    my $parent = 
+	Devel::Trepan::CmdProcessor::Command::Info::Variables->new($grandparent,
+								   'variables');
+    my $cmd = __PACKAGE__->new($parent, 'my');
+
+    eval {
+        sub create_frame() {
+            my ($pkg, $file, $line, $fn) = caller(0);
+            $DB::package = $pkg;
+            return [
+                {
+                    file      => $file,
+                    fn        => $fn,
+                    line      => $line,
+                    pkg       => $pkg,
+                }];
+        }
+    };
+    my $frame_ary = create_frame();
+    $proc->frame_setup($frame_ary);
+
+    $cmd->run($cmd->{prefix}, -2);
+    my @args = @{$cmd->{prefix}};
+    push @args, '$args';
+    print '-' x 40, "\n";
+    $cmd->run(\@args, -2);
+    print '-' x 40, "\n";
+    $cmd->run($cmd->{prefix}, -1);
+    print '-' x 40, "\n";
+    my @complete = $cmd->complete('', -1);
+    print join(', ', @complete), "\n";
+    print '-' x 40, "\n";
+    @complete = $cmd->complete('$p', -1);
+    print join(', ', @complete), "\n";
+
 }
 
 1;
