@@ -326,26 +326,13 @@ sub run($$)
 }
 
 unless (caller) {
-    require Devel::Trepan::CmdProcessor;
+    require Devel::Trepan::CmdProcessor::Mock;
     my $proc = Devel::Trepan::CmdProcessor->new(undef, 'bogus');
     my $cmd = __PACKAGE__->new($proc);
     require Devel::Trepan::DB::Sub;
     require Devel::Trepan::DB::LineCache;
-    eval {
-        sub create_frame() {
-            my ($pkg, $file, $line, $fn) = caller(0);
-            $DB::package = $pkg;
-            return [
-                {
-                    file      => $file,
-                    fn        => $fn,
-                    line      => $line,
-                    pkg       => $pkg,
-                }];
-        }
-    };
     DB::LineCache::cache(__FILE__);
-    my $frame_ary = create_frame();
+    my $frame_ary = Devel::Trepan::CmdProcessor::Mock::create_frame();
     $proc->frame_setup($frame_ary);
     $proc->{settings}{highlight} = 0;
     $cmd->run([$NAME]);
