@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 use strict;
@@ -11,7 +11,14 @@ use Devel::Trepan::CmdProcessor::Command::Subcmd::Core;
 use Devel::Trepan::CmdProcessor::Command::Subcmd::SubsubMgr;
 use vars qw(@ISA @SUBCMD_VARS);
 our $MIN_ABBREV = length('ma');
-our $HELP   = 'Set maximum length for things which may have unbounded size';
+our $HELP   = <<"HELP";
+Set maximum length for things which may have unbounded size.
+
+See C<help set max *> for a list of subcommands or C<help set max I<name>>
+for help on a particular max setting.
+HELP
+our $SHORT_HELP = "Set maximum length sizes of various things";
+
 @ISA = qw(Devel::Trepan::CmdProcessor::Command::SubsubcmdMgr);
 
 unless (caller) { 
